"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.normalizeOptions = void 0;
const tslib_1 = require("tslib");
const devkit_1 = require("@nrwl/devkit");
const node_path_1 = require("node:path");
function normalizeOptions(tree, options) {
    const name = (0, devkit_1.names)(options.name).fileName;
    const projectDirectory = options.directory
        ? `${(0, devkit_1.names)(options.directory).fileName}/${name}`
        : name;
    const projectName = projectDirectory.replace(new RegExp('/', 'g'), '-');
    const projectRoot = `${(0, devkit_1.getWorkspaceLayout)(tree).libsDir}/${projectDirectory}`;
    const parsedTags = options.tags
        ? options.tags.split(',').map((s) => s.trim())
        : [];
    const { configName, introspection, schema, type } = options, libraryGeneratorOptions = tslib_1.__rest(options, ["configName", "introspection", "schema", "type"]);
    const configPath = (0, node_path_1.join)(projectRoot, `${configName}.ts`);
    return {
        configName,
        configPath,
        documents: (0, node_path_1.join)(projectRoot, 'src/**/*.graphql'),
        introspection,
        libraryGeneratorOptions,
        parsedTags,
        projectDirectory,
        projectName,
        projectRoot,
        schema,
        type,
    };
}
exports.normalizeOptions = normalizeOptions;
exports.default = normalizeOptions;
//# sourceMappingURL=normalize-options.js.map